@@ -4,18 +4,15 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
-	"slices"
 	"strings"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/engine"
-	"github.com/jandedobbeleer/oh-my-posh/src/platform"
+	"github.com/jandedobbeleer/oh-my-posh/src/config"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 
 	"github.com/spf13/cobra"
 )
 
-var (
-	output string
-)
+var output string
 
 // exportCmd represents the export command
 var exportCmd = &cobra.Command{
@@ -27,33 +24,49 @@ You can choose to print the output to stdout, or export your config in the forma
 
 Example usage:
 
-> oh-my-posh config export --config ~/myconfig.omp.json
-
-Exports the ~/myconfig.omp.json config file and prints the result to stdout.
-
 > oh-my-posh config export --config ~/myconfig.omp.json --format toml
 
-Exports the ~/myconfig.omp.json config file to toml and prints the result to stdout.`,
+Exports the config file "~/myconfig.omp.json" in TOML format and prints the result to stdout.
+
+> oh-my-posh config export --output ~/new_config.omp.json
+
+Exports the current config to "~/new_config.omp.json" (in JSON format).`,
 	Args: cobra.NoArgs,
 	Run: func(_ *cobra.Command, _ []string) {
-		env := &platform.Shell{
-			CmdFlags: &platform.Flags{
-				Config: config,
+		if len(output) == 0 && len(format) == 0 {
+			// usage error
+			fmt.Println("neither output path nor export format is specified")
+			os.Exit(2)
+		}
+
+		env := &runtime.Terminal{
+			CmdFlags: &runtime.Flags{
+				Config: configFlag,
 			},
 		}
 		env.Init()
 		defer env.Close()
-		cfg := engine.LoadConfig(env)
+		cfg := config.Load(env)
 
-		if len(output) == 0 && len(format) == 0 {
-			// usage error
-			os.Exit(2)
+		validateExportFormat := func() {
+			format = strings.ToLower(format)
+			switch format {
+			case "json", "jsonc":
+				format = config.JSON
+			case "toml", "tml":
+				format = config.TOML
+			case "yaml", "yml":
+				format = config.YAML
+			default:
+				formats := []string{"json", "jsonc", "toml", "tml", "yaml", "yml"}
+				// usage error
+				fmt.Printf("export format must be one of these: %s\n", strings.Join(formats, ", "))
+				os.Exit(2)
+			}
 		}
 
-		formats := []string{"json", "jsonc", "toml", "tml", "yaml", "yml"}
-		if len(format) != 0 && !slices.Contains(formats, format) {
-			// usage error
-			os.Exit(2)
+		if len(format) != 0 {
+			validateExportFormat()
 		}
 
 		if len(output) == 0 {
@@ -65,38 +78,26 @@ Exports the ~/myconfig.omp.json config file to toml and prints the result to std
 
 		if len(format) == 0 {
 			format = strings.TrimPrefix(filepath.Ext(output), ".")
-		}
-
-		switch format {
-		case "json", "jsonc":
-			format = engine.JSON
-		case "toml", "tml":
-			format = engine.TOML
-		case "yaml", "yml":
-			format = engine.YAML
-		default:
-			// data error
-			os.Exit(65)
+			validateExportFormat()
 		}
 
 		cfg.Write(format)
 	},
 }
 
-func cleanOutputPath(path string, env platform.Environment) string {
-	if strings.HasPrefix(path, "~") {
-		path = strings.TrimPrefix(path, "~")
-		path = filepath.Join(env.Home(), path)
-	}
+func cleanOutputPath(path string, env runtime.Environment) string {
+	path = runtime.ReplaceTildePrefixWithHomeDir(env, path)
+
 	if !filepath.IsAbs(path) {
 		if absPath, err := filepath.Abs(path); err == nil {
 			path = absPath
 		}
 	}
+
 	return filepath.Clean(path)
 }
 
-func init() { //nolint:gochecknoinits
+func init() {
 	exportCmd.Flags().StringVarP(&format, "format", "f", "json", "config format to migrate to")
 	exportCmd.Flags().StringVarP(&output, "output", "o", "", "config file to export to")
 	configCmd.AddCommand(exportCmd)
