@@ -11,8 +11,8 @@ func TestBashFeatures(t *testing.T) {
 
 	want := `// these are the features
 _omp_ftcs_marks=1
-$_omp_executable upgrade
-$_omp_executable notice
+"$_omp_executable" upgrade
+"$_omp_executable" notice
 _omp_cursor_positioning=1`
 
 	assert.Equal(t, want, got)
